const express = require('express');
const cors = require('cors');
const config = require('./config');
const summaryRoutes = require('./routes/summary');
const rateLimit = require('express-rate-limit');

const app = express();

// 从环境变量中读取并解析域名列表
const ALLOWED_DOMAINS = process.env.ALLOWED_DOMAINS 
    ? process.env.ALLOWED_DOMAINS.split(',').map(domain => domain.trim())
    : [];

// 域名验证中间件
const validateDomain = (req, res, next) => {
    try {
        const { articleUrl } = req.body;
        if (!articleUrl) {
            return res.status(400).json({
                success: false,
                message: '缺少文章 URL'
            });
        }

        const url = new URL(articleUrl);
        const domain = url.hostname;
        
        // 检查是否是允许的域名或其子域名
        const isAllowedDomain = ALLOWED_DOMAINS.some(allowedDomain => 
            domain === allowedDomain || domain.endsWith('.' + allowedDomain)
        );

        if (!isAllowedDomain) {
            return res.status(403).json({
                success: false,
                message: '不支持该网站的文章摘要生成'
            });
        }

        next();
    } catch (error) {
        res.status(400).json({
            success: false,
            message: '无效的 URL'
        });
    }
};

// 创建全局限速器
const globalLimiter = rateLimit({
    windowMs: 15 * 60 * 1000, // 15分钟时间窗口
    limit: 200, // 每个 IP 在时间窗口内最多 100 次请求
    standardHeaders: true, // 返回 RateLimit-* 头部信息
    legacyHeaders: false, // 禁用 X-RateLimit-* 头部信息
    message: {
        success: false,
        message: '请求过于频繁，请稍后再试'
    }
});

// 创建 API 特定的限速器
const apiLimiter = rateLimit({
    windowMs: 15 * 60 * 1000, // 15分钟时间窗口
    limit: 100, // 每个 IP 在时间窗口内最多 10 次请求
    standardHeaders: true,
    legacyHeaders: false,
    message: {
        success: false,
        message: '摘要生成请求过于频繁，请稍后再试'
    },
    handler: (req, res) => {
        res.status(429).json({
            success: false,
            message: '摘要生成请求过于频繁，请稍后再试',
            nextValidRequestTime: new Date(req.rateLimit.resetTime).toISOString()
        });
    }
});

app.set('trust proxy', 1);

// 应用全局限速器
app.use(globalLimiter);

// 配置 CORS
app.use(cors({
    origin: config.allowedOrigins,
    methods: ['POST'],
    allowedHeaders: ['Content-Type']
}));

// 解析 JSON 请求体
app.use(express.json());

// 在路由之前添加域名验证中间件
app.use('/api', validateDomain);

// 为 /api 路由应用特定的限速器
app.use('/api', apiLimiter);

// 路由
app.use('/api', summaryRoutes);

// 错误处理中间件
app.use((err, req, res, next) => {
    console.error(err.stack);
    res.status(500).json({
        success: false,
        message: 'Internal Server Error'
    });
});

const port = config.port;
app.listen(port, () => {
    console.log(`Server is running on port ${port}`);
});