const express = require('express');
const router = express.Router();
const OpenAI = require('openai');
const config = require('../config');
const logger = require('../utils/logger');
const db = require('../database/db');
const { validateContent, validateUrl } = require('../utils/validators');

// 创建 OpenAI 客户端
const client = new OpenAI({
    apiKey: config.deepseekApiKey,
    baseURL: 'https://api.deepseek.com'
});

router.post('/summarize', async (req, res) => {
    try {
        const { content, articleUrl } = req.body;

        if (!validateContent(content)) {
            return res.status(400).json({
                success: false,
                message: 'Invalid content'
            });
        }

        if (!validateUrl(articleUrl)) {
            return res.status(400).json({
                success: false,
                message: 'Invalid article URL'
            });
        }

        // 检查数据库中是否存在该文章的摘要
        const existingSummary = await db.getSummary(articleUrl);
        const currentHash = db.generateHash(content);

        // 如果存在且内容哈希相同，直接返回缓存的摘要
        if (existingSummary && existingSummary.content_hash === currentHash) {
            logger.info(`Using cached summary for article: ${articleUrl}`);
            return res.json({
                success: true,
                summary: existingSummary.summary,
                fromCache: true,
                lastUpdated: existingSummary.updated_at
            });
        }

        // 内容发生变化或新文章，需要生成新摘要
        logger.info(`Generating new summary for article: ${articleUrl}`);
        const prompt = `请为以下文章生成一个简洁的摘要，突出文章的主要观点：

${content}

请确保摘要简明扼要，并保持原文的核心意思。`;

        const response = await client.chat.completions.create({
            model: "deepseek-chat",
            messages: [
                {
                    role: "system",
                    content: "你是一个专业的文章摘要助手，善于提取文章的核心内容。"
                },
                {
                    role: "user",
                    content: prompt
                }
            ],
            temperature: 0.7
        });

        const summary = response.choices[0].message.content;

        // 保存或更新摘要
        const result = await db.saveSummary(articleUrl, currentHash, summary);
        logger.info(`Summary ${result.isUpdate ? 'updated' : 'saved'} for article: ${articleUrl}`);

        res.json({
            success: true,
            summary,
            fromCache: false,
            isUpdate: result.isUpdate
        });

    } catch (error) {
        logger.error('Error in summary generation:', error);
        res.status(500).json({
            success: false,
            message: error.message
        });
    }
});

module.exports = router;



