(function() {
    // 从脚本标签获取配置
    function getConfig() {
        const script = document.currentScript || document.querySelector('script[src*="blog-summary-animated.js"]');
        return {
            apiEndpoint: script.getAttribute('data-api-endpoint'),
            containerSelector: script.getAttribute('data-container'),
            typingSpeed: parseInt(script.getAttribute('data-typing-speed') || 50, 10)
        };
    }

    // 打字机效果函数
    function typeWriterEffect(element, text, speed) {
        let i = 0;
        element.textContent = "";
        const timer = setInterval(() => {
            if (i < text.length) {
                element.textContent += text.charAt(i);
                i++;
            } else {
                clearInterval(timer);
            }
        }, speed);
    }
    // 修改为自己的接口以及根据实际网页内容修改文章内容选择器
    class BlogSummary {
        constructor(options = {}) {
            this.options = {
                apiEndpoint: options.apiEndpoint || '',
                containerSelector: options.containerSelector || '.joe_detail-wrapper',
                typingSpeed: options.typingSpeed || 50
            };
            this.init();
        }

        async init() {
            this.createSummaryContainer();
            await this.generateSummary();
            this.initThemeObserver();
        }

        createSummaryContainer() {
            const container = document.createElement('div');
            container.className = 'blog-summary-container';
            container.innerHTML = `
                <style>
                    .blog-summary-container {
                        margin: 20px 0;
                        padding: 20px;
                        border-radius: 8px;
                        background: var(--summary-bg);
                        border: 1px solid var(--summary-border);
                        font-family: system-ui, -apple-system, sans-serif;
                        transition: all 0.3s ease;
                    }

                    .blog-summary-header {
                        display: flex;
                        align-items: center;
                        margin-bottom: 15px;
                        gap: 10px;
                    }

                    .blog-summary-icon {
                        width: 24px;
                        height: 24px;
                        background-color: #3b82f6;
                        border-radius: 50%;
                        display: flex;
                        align-items: center;
                        justify-content: center;
                        color: white;
                        font-size: 14px;
                        flex-shrink: 0;
                    }

                    .blog-summary-title {
                        margin: 0;
                        font-size: 16px;
                        font-weight: 600;
                        color: var(--summary-text);
                    }

                    .blog-summary-content {
                        color: var(--summary-text-secondary);
                        line-height: 1.6;
                        font-size: 15px;
                        margin: 0;
                    }

                    .blog-summary-loading {
                        display: flex;
                        align-items: center;
                        gap: 8px;
                        color: var(--summary-loading-color);
                    }

                    .blog-summary-error {
                        color: #ef4444;
                        font-size: 14px;
                    }

                    /* 加载动画 */
                    .loading-dots {
                        display: flex;
                        gap: 4px;
                    }

                    .loading-dots span {
                        width: 6px;
                        height: 6px;
                        border-radius: 50%;
                        background-color: var(--summary-loading-color);
                        animation: loading-dot 1.4s infinite;
                    }

                    .loading-dots span:nth-child(2) {
                        animation-delay: 0.2s;
                    }

                    .loading-dots span:nth-child(3) {
                        animation-delay: 0.4s;
                    }

                    @keyframes loading-dot {
                        0%, 100% { 
                            transform: scale(0.3); 
                            opacity: 0.3; 
                        }
                        50% { 
                            transform: scale(1); 
                            opacity: 1; 
                        }
                    }
                </style>

                <div class="blog-summary-header">
                    <div class="blog-summary-icon">AI</div>
                    <h3 class="blog-summary-title">文章摘要</h3>
                </div>
                <div class="blog-summary-content"></div>
            `;

            const articleContainer = document.querySelector(this.options.containerSelector);
            if (articleContainer) {
                const articleContent = articleContainer.querySelector('.joe_detail__article');
                if (articleContent) {
                    articleContent.insertBefore(container, articleContent.firstChild);
                } else {
                    articleContainer.insertBefore(container, articleContainer.firstChild);
                }
            }
            
            this.summaryContent = container.querySelector('.blog-summary-content');
            this.container = container;
            
            // 初始化主题颜色
            this.updateThemeColors();
        }

        initThemeObserver() {
            // 初始检测主题
            this.updateThemeColors();

            // 创建 MutationObserver 来监视主题变化
            const observer = new MutationObserver(() => {
                this.updateThemeColors();
            });

            // 只监视 HTML 元素的 data-mode 属性变化
            observer.observe(document.documentElement, {
                attributes: true,
                attributeFilter: ['data-mode']
            });
        }

        isDarkMode() {
            // 夜间模式检测，根据实际的网站主题修改
            const mode = document.documentElement.getAttribute('data-mode');
            return mode !== 'light';
        }

        updateThemeColors() {
            const isDark = this.isDarkMode();
            
            if (isDark) {
                // 暗色模式
                this.container.style.cssText = `
                    --summary-bg: #1a1a1a;
                    --summary-border: #333333;
                    --summary-text: #ffffff;
                    --summary-text-secondary: #cccccc;
                    --summary-loading-color: #999999;
                `;
            } else {
                // 亮色模式
                this.container.style.cssText = `
                    --summary-bg: #f8fafc;
                    --summary-border: #e2e8f0;
                    --summary-text: #1e293b;
                    --summary-text-secondary: #475569;
                    --summary-loading-color: #64748b;
                `;
            }
        }

        getArticleContent() {
            const articleContainer = document.querySelector(this.options.containerSelector);
            if (!articleContainer) return null;

            const summaryContainer = articleContainer.querySelector('.blog-summary-container');
            let content = '';

            // 获取文章标题
            const titleElement = document.querySelector('.joe_detail__title');
            if (titleElement) {
                content += `标题：${titleElement.textContent.trim()}\n\n`;
            }

            // 获取文章内容
            const contentElement = articleContainer.querySelector('.joe_detail__article');
            if (contentElement) {
                const elements = contentElement.querySelectorAll('p, h1, h2, h3, h4, h5, h6');
                for (const element of elements) {
                    if (!element.closest('.blog-summary-container') && 
                        !element.closest('.joe_detail__copyright')) {
                        content += element.textContent.trim() + '\n\n';
                    }
                }
            }

            return content.trim();
        }

        getArticleUrl() {
            try {
                const url = new URL(window.location.href);
                url.search = '';
                url.hash = '';
                return url.toString();
            } catch (error) {
                console.error("Invalid URL:", error);
                return window.location.href;
            }
        }

        async generateSummary() {
            const content = this.getArticleContent();
            if (!content) {
                this.showError('无法获取文章内容');
                return;
            }

            const articleUrl = this.getArticleUrl();
            if (!articleUrl) {
                this.showError('无法获取文章 URL');
                return;
            }

            try {
                this.showLoading();
                const summary = await this.fetchSummary(content, articleUrl);
                this.showSummary(summary);
            } catch (error) {
                this.showError(error.message);
            }
        }

        async fetchSummary(content, articleUrl) {
            try {
                const response = await fetch(this.options.apiEndpoint, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({
                        content,
                        articleUrl,
                        options: {
                            maxLength: 1000,
                            style: 'detailed'
                        }
                    })
                });

                if (!response.ok) {
                    throw new Error('获取摘要失败');
                }

                const data = await response.json();
                if (!data.success) {
                    throw new Error(data.message || '获取摘要失败');
                }

                return data.summary;
            } catch (error) {
                throw new Error('网络请求失败，请稍后重试');
            }
        }

        showLoading() {
            this.summaryContent.innerHTML = `
                <div class="blog-summary-loading">
                    <span>正在生成摘要</span>
                    <div class="loading-dots">
                        <span></span>
                        <span></span>
                        <span></span>
                    </div>
                </div>
            `;
        }

        showError(message) {
            this.summaryContent.innerHTML = `<div class="blog-summary-error">${message}</div>`;
        }

        showSummary(summary) {
            this.summaryContent.innerHTML = '<span class="typewriter"></span>';
            typeWriterEffect(this.summaryContent.querySelector('.typewriter'), summary, this.options.typingSpeed);
        }
    }

    // 等待 DOM 加载完成后初始化
    document.addEventListener('DOMContentLoaded', function() {
        new BlogSummary(getConfig());
    });
})();